@@ -15,12 +15,12 @@
  */
 
 #include "myarea.h"
-#include <gtkmm/main.h>
+#include <gtkmm/application.h>
 #include <gtkmm/window.h>
 
 int main(int argc, char** argv)
 {
-  Gtk::Main kit(argc, argv);
+  Glib::RefPtr<Gtk::Application> app = Gtk::Application::create(argc, argv, "org.gtkmm.example");
 
   Gtk::Window win;
   win.set_title("DrawingArea");
@@ -30,7 +30,5 @@ int main(int argc, char** argv)
   win.add(area);
   area.show();
 
-  Gtk::Main::run(win);
-
-  return 0;
+  return app->run(win);
 }
